@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -187,8 +187,8 @@ private:
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    std::vector<Vertex> m_vertices;      ///< Vertices contained in the array
-    PrimitiveType       m_primitiveType; ///< Type of primitives to draw
+    std::vector<Vertex> m_vertices;      //!< Vertices contained in the array
+    PrimitiveType       m_primitiveType; //!< Type of primitives to draw
 };
 
 } // namespace sf
